function [FigHandleOut]=GenerateHFRosePlotColor(PolarDataIn)
%
%  [FigHandleOut]=GenerateHFRosePlotColor(PolarDataIn);
%
%  PolarDataIn is a matrix consisting of 5 columns:
%     [AngleBinStart AngleBinEnd SpeedBinStart SpeedBinEnd Percentage]
%
%  Circles are placed at 10% and 20% (10 and 20 percent)
%
%
%  Contact Info:  Chris Halle
%                 cmhalle@ucdavis.edu
%
% Code governed by the same public license as the HF Radar Toolbox:
%  Basically, let others know if you update it!
%
% Copyright (C) 2008 Chris Halle
% Licence: GPL (Gnu Public License)
%
%  Step 1 - find the maximum total percentage per angle
%           will be used to scale figure
%
[AngleDivisions,AngleIndicesDiv,TemIndex]=unique(PolarDataIn(:,1:2),'rows');
SumPercentages=NaN*zeros(1,numel(AngleIndicesDiv));
for jdiv=1:numel(AngleIndicesDiv),
    temmark=find(ismember(PolarDataIn(:,1:2),AngleDivisions(jdiv,:),'rows'));
    SumPercentages(jdiv)=sum(PolarDataIn(temmark,5));
end
%
MaxPercentage=max(SumPercentages);
%
%  Step 2 - Get scale for figure.  Have percentage circles be in blocks of
%  20
%
MaxScaleStart=floor(MaxPercentage/20);
MaxScaleAdd=sign(rem(MaxPercentage,20));
MaxScaleForFigure=(MaxScaleStart+MaxScaleAdd)*20;
%
%  Step 3.  Get the colorbar for the filled regions.
%
AllSpeedBins=unique(PolarDataIn(:,3:4),'rows');
[SpeedStart,IndexStart]=sort(AllSpeedBins(:,1),'ascend');
AllSpeedBins=AllSpeedBins(IndexStart,:);  % now sorted, smallest to highest
%
%  start the color bar with the color [0.4 0.4 0.4]
%   %%% commented out section is from the black and white version
%ColorBarSpacing=(0.9-0.4)/(numel(IndexStart)-1);
%ColorBarIndex=0.4:ColorBarSpacing:0.9;
%if max(ColorBarIndex)<0.9,  % account for roundoff
%    ColorBarIndex=[ColorBarIndex 0.9];
%end
%
%ColorBarMap=[ColorBarIndex' ColorBarIndex' ColorBarIndex'];
FigHandleOut=figure;
%
ColorBarMap=colormap(jet(numel(IndexStart)));
%
%  Step 4 - Loop and plot up the patches.  Could do all at once,
%  but really no need, will be fast enough.
%
%
PlotAlready=0;
%
for jangle=1:numel(AngleIndicesDiv),
    %
    AnglesIndices=find(ismember(PolarDataIn(:,1:2),AngleDivisions(jangle,:),'rows'));
    SpeedsToPlot=PolarDataIn(AnglesIndices,3:5);
    [SpeedsHere,IndexToSort]=sort(SpeedsToPlot(:,1),'ascend');
    SpeedsToPlot=SpeedsToPlot(IndexToSort,:);
    %
    CurrentAnglePercentage=0;
    %
    for jspeed=1:numel(SpeedsToPlot(:,1)),
        %
        if SpeedsToPlot(jspeed,3)>0,
             %
             ColorBinToPlot=find(ismember(AllSpeedBins,SpeedsToPlot(jspeed,1:2),'rows'));
             %
             EndRadius=CurrentAnglePercentage+SpeedsToPlot(jspeed,3);
             %
             SerToPlot=GetPolarCoordsToPlot(AngleDivisions(jangle,:),CurrentAnglePercentage,EndRadius);
             %
             patch(SerToPlot(1,:),SerToPlot(2,:),ColorBarMap(ColorBinToPlot,:));
             %
             CurrentAnglePercentage=EndRadius;
             %
             if ~PlotAlready,
                 hold
                 PlotAlready=1;
             end
             %
        end
    end
end
%
axis equal
%
%  Step 5 - Plot up the percentage circles and the East/West axes
%
MinorAxesPlot=10:10:MaxScaleForFigure;
MajorAxesPlot=20:20:MaxScaleForFigure;
%
TemAngle=0:0.05:360;
%
for jplot=1:numel(MinorAxesPlot),
    %
    TemX=MinorAxesPlot(jplot)*cos((2*pi/360)*TemAngle);
    TemY=MinorAxesPlot(jplot)*sin((2*pi/360)*TemAngle);
    %
    plot(TemX,TemY,'k--','LineWidth',[1])
    %
end
%
for jplot=1:numel(MajorAxesPlot),
    %
    TemX=MajorAxesPlot(jplot)*cos((2*pi/360)*TemAngle);
    TemY=MajorAxesPlot(jplot)*sin((2*pi/360)*TemAngle);
    %
    plot(TemX,TemY,'k','LineWidth',[2])
    %
end
%
%  remove the ticks and tick labels
%
set(gca,'XTick',[])
set(gca,'YTick',[])
%
%  plot the northern arrow and the western arrow (and the east and south)
%
plot([0 0],[0 MaxScaleForFigure+10],'k','LineWidth',[2])
plot([-1*(MaxScaleForFigure+10) 0],[0 0],'k','LineWidth',[2])
plot([0 0],[-1*(MaxScaleForFigure+10) 0],'k','LineWidth',[1])
plot([0 (MaxScaleForFigure+10)],[0 0],'k','LineWidth',[1])
%
%  labeling
%
text(MaxScaleForFigure/20,MaxScaleForFigure+7,'N','FontSize',20,'FontWeight','bold')
text(-1*(MaxScaleForFigure+7),-1*MaxScaleForFigure/20,'W','FontSize',20,'FontWeight','bold')
PercentLabel=[num2str(MaxScaleForFigure) ' %'];
text(MaxScaleForFigure+2,-1*MaxScaleForFigure/10,PercentLabel,'FontSize',20,'FontWeight','bold')
%
if numel(MajorAxesPlot)>1,
    PercentIndexToGrab=round(numel(MajorAxesPlot)/2);
    PercentLabel=[num2str(MajorAxesPlot(PercentIndexToGrab))];
    PlotLocVal=MajorAxesPlot(PercentIndexToGrab);
    text(PlotLocVal,-1*MaxScaleForFigure/10,PercentLabel,'FontSize',20,'FontWeight','bold')
else
    PercentLabel=[num2str(MinorAxesPlot(numel(MinorAxesPlot)))];
    PlotLocVal=MinorAxesPlot(numel(MinorAxesPlot));
    text(PlotLocVal,-1*MaxScaleForFigure/10,PercentLabel,'FontSize',20,'FontWeight','bold')
end
%
%  deal with the colormap
%
colormap(ColorBarMap);
ColorBarHandle=colorbar('vert');
set(ColorBarHandle,'YTick',[0:1/numel(AllSpeedBins(:,1)):numel(AllSpeedBins(:,1))])
LabelTem=num2str([AllSpeedBins(:,1);max(max(AllSpeedBins))],4);
set(ColorBarHandle,'YTickLabel',LabelTem);
set(ColorBarHandle,'FontSize',[20])
set(ColorBarHandle,'FontWeight','bold')
%    
%  the routine is done
%
return;
%
function [SerToPlot]=GetPolarCoordsToPlot(AngleLimitsIn,InnerRadius,OuterRadius)
%
%  [SerToPlot]=GetPolarCoordsToPlot(AngleLimitsIn,InnerRadius,OuterRadius);
%
%  Returns the vertex points of the patch to plot
%  X-axis locations are in the first row, y-axis in the second
%  Directions defined clockwise from north, in degrees
%
TemTheta=AngleLimitsIn(1):0.05:AngleLimitsIn(2);
%
RadFactor=(2*pi/360);
%
%  Get vertex points on inner radius
%
TemX=InnerRadius*sin(RadFactor*TemTheta);
TemY=InnerRadius*cos(RadFactor*TemTheta);
SerToPlot=[TemX;TemY];
%
%  Get vertex points along AngleLimitsIn(2)
%
TemX=sin(RadFactor*AngleLimitsIn(2))*[InnerRadius OuterRadius];
TemY=cos(RadFactor*AngleLimitsIn(2))*[InnerRadius OuterRadius];
TemSer=[TemX;TemY];
SerToPlot=[SerToPlot TemSer];
%
%  Get points along outer radius
%
TemTheta=AngleLimitsIn(2):-0.05:AngleLimitsIn(1);
%
TemX=OuterRadius*sin(RadFactor*TemTheta);
TemY=OuterRadius*cos(RadFactor*TemTheta);
TemSer=[TemX;TemY];
SerToPlot=[SerToPlot TemSer];
%
%  Get points along AngleLimitsIn(1)
%
TemX=sin(RadFactor*AngleLimitsIn(1))*[OuterRadius InnerRadius];
TemY=cos(RadFactor*AngleLimitsIn(1))*[OuterRadius InnerRadius];
TemSer=[TemX;TemY];
SerToPlot=[SerToPlot TemSer];
%
%  the routine is done
%
return;
%
